'use strict';
/*
 * This file specifies whole configuration of sitegin.
 * It reads config file from content/config.toml it also parses command-line
 * arguments. CLI args take precedence over config options
 */
var Git = require('nodegit');
var cli = require('cli');
var fs = require('fs');
var path = require('path');
var toml = require('toml');
var options = cli.parse({
 noserver: ['n', 'Dont run server'],
 port: ['p', 'Port on which server should run', 'number', 1337],
 uiport: [null, 'BrowserSync UI port', 'number', 'port+1'],
 httpsonly: [null, 'Converts all http://ok1kvk.cz links to https'],
 httponly: [null, 'Converts all https://ok1kvk.cz links to http'],
 contentdir: [null, 'Allows to specify arbitrary content directory.', 'string', 'content'],
 themedir: [null, 'Allows to specify arbitrary content directory.', 'string', 'theme'],
 builddir: [null, 'Allows to specify arbitrary content directory.', 'string', null],
 staticdir: [null, 'Allows to specify arbitrary directory for static files.', 'string', 'static']
});

module.exports = function() {
  console.log('Build step: Config');
  var builddir = 'build';
  if(options.builddir)
    builddir = options.builddir;
  else if(!options.noserver) builddir = 'build-debug';

  if(options.uiport == 'port+1') {
    options.uiport = options.port+1;
  }

  return new Promise(function(resolve, reject) {
    var config = {
      options: options,
      builddir: builddir,
      sourceDir: options.contentdir,
      staticDir: options.staticdir,
      themeDir: options.themedir,
      articlesLocation: 'articles',
      redirectsLocation: 'redirects',
      linksPerPage: 6
    };
    var configFile = path.join(config.sourceDir, 'config.toml');
    fs.readFile(configFile,'utf-8',function(err,data) {
      if(err) {
        console.log('Failed to read configuration from '+configFile);
        console.log('Using defaults')
        return resolve({config: config});
      }
      data = toml.parse(data);
      console.log('data: '+data);
      for(let attr in config) { data[attr] = config[attr]; }
      resolve({config: data});
    })
  })
}
module.exports.watch = !options.noserver;
module.exports.themeDir = options.themedir;
